SexSingleEnum-class: Enum to describe possible sexes in an insurance contract or...

SexSingleEnum-classR Documentation

Enum to describe possible sexes in an insurance contract or tariff.

Description

Enum to describe possible sexes in an insurance contract or tariff.

Details

Currently, the only possible values are:

  • "unisex"

  • "male"

  • "female"


LifeInsureR documentation built on June 15, 2025, 1:08 a.m.