applyHook: If 'hook' is a function, apply it to 'val', otherwise return...

View source: R/HelperFunctions.R

applyHookR Documentation

If hook is a function, apply it to val, otherwise return val unchanged

Description

If hook is a function, apply it to val, otherwise return val unchanged

Usage

applyHook(hook, val, ...)

Arguments

hook

(optional) function to apply to val and the other parameters

val

The value to which the hook is applied (ifgiven)

...

optional parameters passed to the hook function (if it is a function)

Value

the value with the hook function applied (if a function) or unchanged otherwiese

Examples

applyHook(NULL, 3) # returns 3 unchanged
applyHook(function(x) 2*x, 3) # applies the function, returns 6
applyHook(`+`, 3, 1) # returns 4

LifeInsureR documentation built on June 15, 2025, 1:08 a.m.